{% extends "cms_bootstrap_templates/base.html" %}
{% load cms_tags sekizai_tags menu_tags placeholder_tags %}

{% block content %}
<div class="col-md-6">
    {% placeholder left_column %}
</div>
<div class="col-md-6">
    {% placeholder right_column %}
</div>
{% endblock %}
